<img src="./docs_src/static/matbench_logo_with_text.png" alt="logo" width="300"/>

matbench is an ImageNet for materials science; a set of 13 (with more to come!) curated machine learning tasks for benchmarking and performance testing.


| Tests  |   Release |
|:----------:|:------:|
| ![example workflow](https://github.com/hackingmaterials/matbench/actions/workflows/python-package.yml/badge.svg) | [![PyPI version](https://img.shields.io/pypi/v/matbench.svg?colorB=blue)](https://pypi.org/project/matbench/) |

- [**Website**](https://matbench.materialsproject.org)
    - [**Leaderboard**](https://matbench.materialsproject.org)
    - [**Per-task leaderboards**](https://matbench.materialsproject.org/Per-Task%20Leaderboards/matbench_v0.1_matbench_dielectric/)
    - [**Documentation**](https://matbench.materialsproject.org/How%20To%20Use/1install/)
    - [**Full benchmark data**](https://matbench.materialsproject.org/Full%20Benchmark%20Data/matbench_v0.1_automatminer_expressv2020/)
    - [**Code reference**](https://matbench.materialsproject.org/Reference/MatbenchBenchmark/)


- [**Help/Support:**](https://discuss.matsci.org/c/matminer)
- [**Source**](https://github.com/materialsproject/matbench)

If you find `matbench` useful, please consider citing [our paper](https://doi.org/10.1038/s41524-020-00406-3):

```
Dunn, A., Wang, Q., Ganose, A., Dopp, D., Jain, A. Benchmarking Materials Property
Prediction Methods: The Matbench Test Set and Automatminer Reference Algorithm. npj 
Computational Materials 6, 138 (2020). https://doi.org/10.1038/s41524-020-00406-3
```

Matbench is pip installable! Install with `pip install matbench` or see [the installation page](https://matbench.materialsproject.org/How%20To%20Use/1install/) for more details.

Python versions 3.9 and 3.10 are supported.